Compression, decompression and storage parameters
=================================================

Dataclasses for setting the compression, decompression and storage parameters. All their parameters are optional.

.. currentmodule:: blosc2

CParams
-------

.. autosummary::
   :toctree: autofiles/storage
   :nosignatures:

    CParams

DParams
-------

.. autosummary::
   :toctree: autofiles/storage
   :nosignatures:

    DParams

Storage
-------

.. autosummary::
   :toctree: autofiles/storage
   :nosignatures:

    Storage
